==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/items/NodeNotesTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class NodeNotesTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.goros.unit.box.ui.datasources.model.Note, UnitBox> {
	public _54_5_01483733402 _54_5_01483733402;
	public NodeNotesTableOperationsItem._54_5_01483733402. Remove remove;

    public NodeNotesTableOperationsItem(UnitBox box) {
        super(box);
        id("a_633608022");
    }

    @Override
	public void init() {
		super.init();
		if (_54_5_01483733402 == null) _54_5_01483733402 = register(new _54_5_01483733402(box()).<_54_5_01483733402>id("a775533165").owner(NodeNotesTableOperationsItem.this));
		if (_54_5_01483733402 != null) remove = _54_5_01483733402.remove;
	}

	public class _54_5_01483733402 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public NodeNotesTableOperationsItem._54_5_01483733402. Remove remove;

		public _54_5_01483733402(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (remove == null) remove = register(new Remove(box()).<Remove>id("a_1673783525").owner(NodeNotesTableOperationsItem.this));
		}

		public class Remove extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Remove(UnitBox box) {
				super(box);
				_title("Eliminar nota");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("Clear");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/items/NodeNotesTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class NodeNotesTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.goros.unit.box.ui.datasources.model.Note, UnitBox> {
	public _54_5_11878419979 _54_5_11878419979;
	public NodeNotesTableOperationsItem._54_5_11878419979. Remove remove;

    public NodeNotesTableOperationsItem(UnitBox box) {
        super(box);
        id("a_633608022");
    }

    @Override
	public void init() {
		super.init();
		if (_54_5_11878419979 == null) _54_5_11878419979 = register(new _54_5_11878419979(box()).<_54_5_11878419979>id("a_1349111400").owner(NodeNotesTableOperationsItem.this));
		if (_54_5_11878419979 != null) remove = _54_5_11878419979.remove;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_54_5_11878419979 != null) _54_5_11878419979.unregister();
	}

	public class _54_5_11878419979 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public NodeNotesTableOperationsItem._54_5_11878419979. Remove remove;

		public _54_5_11878419979(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (remove == null) remove = register(new Remove(box()).<Remove>id("a_1673783525").owner(NodeNotesTableOperationsItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (remove != null) remove.unregister();
		}

		public class Remove extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Remove(UnitBox box) {
				super(box);
				_title("Eliminar nota");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("Clear");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
